#
# spec file for package evemu
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Let the distro decide if py2 support is still valid. TW disables it
%bcond_without python2

%define soname  libevemu
%define sover   3
Name:           evemu
Version:        2.7.0
Release:        3.17
Summary:        Input Event Device Emulation Library
License:        GPL-3.0-only
Group:          Hardware/Other
URL:            https://freedesktop.org/wiki/Evemu
Source:         https://freedesktop.org/software/%{name}/%{name}-%{version}.tar.xz
Source1:        https://freedesktop.org/software/%{name}/%{name}-%{version}.tar.xz.sig
Source2:        %{name}.keyring
BuildRequires:  asciidoc
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
%if %{with python2}
BuildRequires:  python2-devel
%endif
BuildRequires:  python3-devel
BuildRequires:  xmlto
BuildRequires:  pkgconfig(libevdev) >= 1.2.99.902
Provides:       %{name}-tools = %{version}
Obsoletes:      %{name}-tools < %{version}

%description
The evemu library and tools are used to describe devices, record
data, create emulation devices and replay data from kernel evdev
(input event) devices.

%package -n %{soname}%{sover}
Summary:        Input Event Device Emulation Library
Group:          System/Libraries

%description -n %{soname}%{sover}
The evemu library and tools are used to describe devices, record
data, create emulation devices and replay data from kernel evdev
(input event) devices.

%package -n python2-%{name}
Summary:        Python2 bindings for evemu
Group:          Development/Languages/Python
Requires:       %{soname}%{sover} = %{version}
# python-evemu was last used in openSUSE Leap 42.3.
Provides:       python-%{name} = %{version}-%{release}
Obsoletes:      python-%{name} < %{version}-%{release}

%description -n python2-%{name}
The evemu library and tools are used to describe devices, record
data, create emulation devices and replay data from kernel evdev
(input event) devices.

This package provides the Python2 bindings for evemu.

%package -n python3-%{name}
Summary:        Python3 bindings for evemu
Group:          Development/Languages/Python
Requires:       %{soname}%{sover} = %{version}

%description -n python3-%{name}
The evemu library and tools are used to describe devices, record
data, create emulation devices and replay data from kernel evdev
(input event) devices.

This package provides the Python3 bindings for evemu.

%package devel
Summary:        Development files for evemu
Group:          Development/Tools/Other
Requires:       %{name} = %{version}
Requires:       %{soname}%{sover} = %{version}

%description devel
The evemu library and tools are used to describe devices, record
data, create emulation devices and replay data from kernel evdev
(input event) devices.

This package provides the development files.

%prep
%autosetup
evdev_sover="$(basename "$(readlink -f %{_libdir}/libevdev.so)")"
sed -i \
  -e 's|\"%{soname}.so\"|\"%{soname}.so.%{sover}\"|' \
  -e "s|\"libevdev.so\"|\"$evdev_sover\"|"           \
  python/%{name}/{base,const}.py

%build
%global _configure ../configure
%if  %{with python2}
PYTHONS=python2
%endif
PYTHONS="$PYTHONS python3"
for py in $PYTHONS; do
    export PYTHON=$py
    mkdir -p build-$py
    pushd build-$py
    %configure \
      --disable-static       \
      --disable-silent-rules \
      --disable-tests
    make %{?_smp_mflags}
    popd
done

%install
%if %{with python2}
%make_install -C build-python2
%endif
%make_install -C build-python3

find %{buildroot} -type f -name "*.la" -delete -print

# Remove useless "optimised" Python byte-code.
rm -f %{buildroot}%{python_sitelib}/%{name}/*.pyo \
  %{buildroot}%{python3_sitelib}/%{name}/__pycache__/*.opt-?.pyc

%fdupes %{buildroot}%{_bindir}/
%fdupes %{buildroot}%{_mandir}/
%if %{with python2}
%fdupes %{buildroot}%{python2_sitelib}
%endif

%post -n %{soname}%{sover} -p /sbin/ldconfig

%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files
%license COPYING
%{_bindir}/%{name}-*
%{_mandir}/man?/%{name}-*?%{?ext_man}

%files -n %{soname}%{sover}
%license COPYING
%{_libdir}/%{soname}.so.%{sover}*

%if %{with python2}
%files -n python2-%{name}
%license COPYING
%{python2_sitelib}/%{name}/
%endif

%files -n python3-%{name}
%license COPYING
%{python3_sitelib}/%{name}/

%files devel
%{_includedir}/%{name}.h
%{_libdir}/%{soname}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Tue May  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Let distros decide if they still want to build python2 bindings
  (bcond_without python2). Tumbleweed disables this by now.
* Mon May  4 2020 Luigi Baldoni <aloisio@gmx.com>
- Use explicit python2 references
- Spec cleanup
* Mon Mar 12 2018 sor.alexei@meowr.ru
- Update to version 2.7.0:
  * No changelog available.
- Use GPG signing.
- Rename python-evemu to python2evemu for Leap 15.0 or later.
* Mon Aug  1 2016 sor.alexei@meowr.ru
- Fix python binding crashes.
- Add python3-evemu package.
- Remove "optimised" Python byte-code files.
* Mon Aug  1 2016 jslaby@suse.com
- run fdupes (on a per dir basis) to avoid 5 or so duplicates
* Sat Oct 10 2015 sor.alexei@meowr.ru
- Update to 2.1.0.
- Spec cleanup.
* Mon Dec 22 2014 tchvatal@suse.com
- Obsolete tools and use just the pkgname for them
- Cleanup a bit
* Sat Aug 11 2012 nmo.marques@gmail.com
- update to version 1.0.10
- package rename from 'utouch-evemu' to 'evemu', compliancy with
  upstream; should be peaceful, no one should have it installed.
* Thu Aug  9 2012 nmo.marques@gmail.com
- cleanups on spec and re-organized sub-packages
* Sun Aug  5 2012 nmo.marques@gmail.com
- initial package
